===============================
frigg-runner
===============================

.. image:: https://badge.fury.io/py/frigg-runner.png
    :target: http://badge.fury.io/py/frigg-runner

.. image:: https://pypip.in/d/frigg-runner/badge.png
        :target: https://pypi.python.org/pypi/frigg-runner

.. image:: https://ci.frigg.io/badges/eirsyl/frigg-runner/
        :target: https://ci.frigg.io/eirsyl/frigg-runner/

.. image:: http://ci.frigg.io/badges/coverage/eirsyl/frigg-runner/
        :target: https://ci.frigg.io/eirsyl/frigg-runner/

Frigg runner, execute .frigg.yml file localy.

* Free software: MIT license
